from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check
from checkov.common.util.type_forcers import force_list


class NginxIngressCVE202125742Alias(BaseK8Check):

    def __init__(self):
        name = "Prevent NGINX Ingress annotation snippets which contain alias statements See CVE-2021-25742"
        id = "CKV_K8S_154"
        supported_kind = ['Ingress']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)

    def scan_spec_conf(self, conf):

        if conf["metadata"]:
            if conf["metadata"].get('annotations'):
                for annotation in force_list(conf["metadata"]["annotations"]):
                    for key, value in annotation.items():
                        if "snippet" in key and "alias" in value:
                            return CheckResult.FAILED
        return CheckResult.PASSED

check = NginxIngressCVE202125742Alias()



"""
Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""
import json
import logging

from checkov.common.parsers.json.decoder import Decoder
from checkov.common.parsers.json.errors import DecodeError

LOGGER = logging.getLogger(__name__)


def load(filename, allow_nulls=True):
    """
    Load the given JSON file
    """

    content = ''

    with open(filename) as fp:
        content = fp.read()
        fp.seek(0)
        file_lines = [(ind + 1, line) for (ind, line) in
                      list(enumerate(fp.readlines()))]

    return (json.loads(content, cls=Decoder, allow_nulls=allow_nulls), file_lines)


def parse(filename, allow_nulls=True):
    template = None
    template_lines = None
    try:
        (template, template_lines) = load(filename, allow_nulls)
    except DecodeError:
        pass
    except json.JSONDecodeError:
        # Most parsing errors will get caught by the exception above. But, if the file
        # is totally empty, and perhaps in other specific cases, the json library will
        # not even begin parsing with our custom logic that throws the exception above,
        # and will fail with this exception instead.
        pass
    except UnicodeDecodeError:
        pass

    return (template, template_lines)



from typing import Any, List, Dict

from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class GoogleSubnetworkPrivateGoogleEnabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that private_ip_google_access is enabled for Subnet"
        id = "CKV_GCP_74"
        supported_resources = ("google_compute_subnetwork",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "private_ip_google_access"


check = GoogleSubnetworkPrivateGoogleEnabled()



from typing import List

from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.util.secrets import string_has_secrets, AWS, GENERAL


class LambdaEnvironmentCredentials(BaseResourceCheck):
    def __init__(self):
        name = "Ensure no hard-coded secrets exist in lambda environment"
        id = "CKV_AWS_45"
        supported_resources = ["AWS::Lambda::Function", "AWS::Serverless::Function"]
        categories = [CheckCategories.SECRETS]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        self.evaluated_keys = ['Properties/Environment/Variables']
        if 'Properties' in conf.keys():
            properties = conf['Properties']
            if 'Environment' in properties.keys():
                environment = properties['Environment']
                if 'Variables' in environment.keys():
                    variables = environment['Variables']
                    if isinstance(variables, dict):
                        for var_name, value in variables.items():
                            if string_has_secrets(str(value), AWS, GENERAL):
                                self.evaluated_keys = [f'Properties/Environment/Variables/{var_name}']
                                return CheckResult.FAILED

        return CheckResult.PASSED


check = LambdaEnvironmentCredentials()



from abc import abstractmethod
from typing import List, Type, Optional, Dict, Tuple, Any

from checkov.common.graph.db_connectors.db_connector import DBConnector
from checkov.common.graph.graph_builder.local_graph import LocalGraph


class GraphManager:
    def __init__(self, db_connector: DBConnector, parser, source: str = "") -> None:
        self.db_connector = db_connector
        self.source = source
        self.parser = parser

    @abstractmethod
    def build_graph_from_source_directory(
        self,
        source_dir: str,
        render_variables: bool = True,
        local_graph_class: Type[LocalGraph] = LocalGraph,
        parsing_errors: Optional[Dict[str, Exception]] = None,
        download_external_modules: bool = False,
        excluded_paths: Optional[List[str]] = None,
    ) -> Tuple[LocalGraph, Dict[str, Dict[str, Any]]]:
        pass

    @abstractmethod
    def build_graph_from_definitions(
        self, definitions: Dict[str, Dict[str, Any]], render_variables: bool = True
    ) -> LocalGraph:
        pass

    def save_graph(self, graph):
        return self.db_connector.save_graph(graph)

    def get_reader_endpoint(self):
        return self.db_connector.get_reader_endpoint()

    def get_writer_endpoint(self):
        return self.db_connector.get_writer_endpoint()

    def disconnect_from_db(self):
        self.db_connector.disconnect()



from checkov.terraform.checks.resource.aws import *
from checkov.terraform.checks.resource.gcp import *
from checkov.terraform.checks.resource.azure import *
from checkov.terraform.checks.resource.github import *
from checkov.terraform.checks.resource.linode import *
from checkov.terraform.checks.resource.oci import *
from checkov.terraform.checks.resource.openstack import *
from checkov.terraform.checks.resource.panos import *
from checkov.terraform.checks.resource.digitalocean import *



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck

class APIGatewayAuthorization(BaseResourceCheck):

    def __init__(self):
        name = "Ensure there is no open access to back-end resources through API"
        id = "CKV_AWS_59"
        supported_resources = ['AWS::ApiGateway::Method']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'Properties' in conf.keys():
            if 'HttpMethod' in conf['Properties'].keys() and 'AuthorizationType' in conf['Properties'].keys():
                if conf['Properties']['HttpMethod'] != "OPTIONS" and conf['Properties']['AuthorizationType'] == "NONE":
                    if 'ApiKeyRequired' not in conf['Properties'].keys() or conf['Properties']['ApiKeyRequired'] is False:
                        return CheckResult.FAILED
        return CheckResult.PASSED

check = APIGatewayAuthorization()



from typing import List, Optional, Any, Dict

from checkov.common.graph.checks_infra.enums import Operators
from .greater_than_attribute_solver import GreaterThanAttributeSolver


class LessThanOrEqualAttributeSolver(GreaterThanAttributeSolver):
    operator = Operators.LESS_THAN_OR_EQUAL

    def __init__(self, resource_types: List[str], attribute: Optional[str], value: Any) -> None:
        super().__init__(resource_types=resource_types, attribute=attribute, value=value)

    def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
        if vertex.get(attribute) is None:
            return False

        return not super()._get_operation(vertex, attribute)



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class AppServiceDetailedErrorMessagesEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that App service enables detailed error messages"
        id = "CKV_AZURE_65"
        supported_resources = ['azurerm_app_service']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "logs/[0]/detailed_error_messages_enabled"


check = AppServiceDetailedErrorMessagesEnabled()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_negative_value_check import BaseResourceNegativeValueCheck
from checkov.common.models.consts import ANY_VALUE


class ComputeInstanceAdminPassword(BaseResourceNegativeValueCheck):
    def __init__(self):
        name = "Ensure that instance does not use basic credentials"
        id = "CKV_OPENSTACK_4"
        supported_resources = ['openstack_compute_instance_v2']
        categories = [CheckCategories.SECRETS]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_attribute_result=CheckResult.PASSED)

    def get_inspected_key(self) -> str:
        return 'admin_pass'

    def get_forbidden_values(self):
        return [ANY_VALUE]


check = ComputeInstanceAdminPassword()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class ECSTaskDefinitionEFSVolumeEncryption(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Encryption in transit is enabled for EFS volumes in ECS Task definitions"
        id = "CKV_AWS_97"
        supported_resources = ['aws_ecs_task_definition']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        self.evaluated_keys = ['volume']
        if 'volume' in conf.keys():
            for volume_idx, volume in enumerate(conf['volume']):
                if isinstance(volume, dict) and 'efs_volume_configuration' in volume:
                    for efs_idx, efs in enumerate(volume['efs_volume_configuration']):
                        if isinstance(efs, dict):
                            self.evaluated_keys = [f'volume/[{volume_idx}]/efs_volume_configuration/[{efs_idx}]']
                            if 'transit_encryption' in efs and efs['transit_encryption'] == ['ENABLED']:
                                return CheckResult.PASSED
                            return CheckResult.FAILED
        return CheckResult.PASSED


check = ECSTaskDefinitionEFSVolumeEncryption()



from checkov.cloudformation.checks.resource.aws.AbsSecurityGroupUnrestrictedIngress import AbsSecurityGroupUnrestrictedIngress


class SecurityGroupUnrestrictedIngress3389(AbsSecurityGroupUnrestrictedIngress):
    def __init__(self):
        super().__init__(check_id="CKV_AWS_25", port=3389)


check = SecurityGroupUnrestrictedIngress3389()
